@@ -1,5 +1,8 @@
-from ddtrace import compat
-from ddtrace.vendor import attr
+import typing
+
+import attr
+
+from ddtrace.internal import compat
 
 
 def event_class(klass):
@@ -41,5 +44,7 @@ class StackBasedEvent(SampleEvent):
     task_name = attr.ib(default=None)
     frames = attr.ib(default=None)
     nframes = attr.ib(default=None)
-    trace_ids = attr.ib(default=None)
-    span_ids = attr.ib(default=None)
+    trace_id = attr.ib(default=None)
+    span_id = attr.ib(default=None)
+    trace_type = attr.ib(default=None, type=typing.Optional[str])
+    trace_resource = attr.ib(default=None, type=typing.Optional[str])
